<script setup>
import { ref } from "vue";

const props = defineProps({
	offset: {
		type: Array,
		default() {
			return [0, 0];
		},
	},
	color: {
		type: String,
		default: "#fff",
	},
	text: {
		type: [String, Array],
		default: 'Text',
	},
	fontSize: {
		type: [Number, String],
		default: 16,
	},
	textAnchor: {
		type: String,
		validator: (v) => ["start", "middle", "end"].includes(v),
		default: 'start',
	},
  isVertical: {
    type: Boolean,
    default: false
  }
});
</script>

<template>
  <g ref="g" :transform="'translate(' + offset.join(',') + ')'">
    <text
      v-if="typeof props.text === 'string'"
      :dy="fontSize/2"
      :fill="color"
      :text-anchor="textAnchor"
      :font-size="fontSize"
      :writing-mode="isVertical ? 'vertical-rl' : 'horizontal-tb'"
      style="text-orientation: upright;"
      >{{ text }}</text
    >
    <text
      v-else
      :fill="color"
      :text-anchor="textAnchor"
      :font-size="fontSize"
      :writing-mode="isVertical ? 'vertical-rl' : 'horizontal-tb'"
      style="text-orientation: upright;"
      >
      <tspan :dy="fontSize / 2" :x="isVertical ? (idx - (props.text.length - 1) / 2) * fontSize * 1.2 : 0" :y="isVertical ? 0 : (idx - (props.text.length - 1) / 2) * fontSize * 1.2" v-for="(item, idx) in props.text" :key="'t_' + idx">
        {{ item }}
      </tspan>
      </text
    >
  </g>
</template>

<style scoped lang="less"></style>
